#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""TUI screen modules."""

try:
    from .main_screen import MainScreen  # noqa: F401
    SCREENS_AVAILABLE = True
except ImportError:
    SCREENS_AVAILABLE = False
