# Example friTap plugins
#
# Available examples:
#   stats_plugin        - Statistics collection plugin
#   module_logger_plugin - Module load logging plugin
#   custom_aes          - Minimal AES key capture (CustomProtocolPlugin)
#   srtp                - SRTP data capture (CustomProtocolPlugin)
#   wireguard           - WireGuard key extraction (CustomProtocolPlugin)
